summaryrefslogtreecommitdiffstats
path: root/chrome/browser/plugin_process_host.h
diff options
context:
space:
mode:
authoravi@google.com <avi@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-06 21:39:04 +0000
committeravi@google.com <avi@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-06 21:39:04 +0000
commit28ab7f9770e0096536e5277c62f5463625f152bd (patch)
treefd7db6edfb8ad20a39944ac3d438d2ca4738c1fb /chrome/browser/plugin_process_host.h
parentd7bb1f68d48f5939c9579fbfacd82389096b776c (diff)
downloadchromium_src-28ab7f9770e0096536e5277c62f5463625f152bd.zip
chromium_src-28ab7f9770e0096536e5277c62f5463625f152bd.tar.gz
chromium_src-28ab7f9770e0096536e5277c62f5463625f152bd.tar.bz2
Change "dll" to "plugin" where appropriate.
Review URL: http://codereview.chromium.org/16543 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@7617 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/plugin_process_host.h')
-rw-r--r--chrome/browser/plugin_process_host.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/plugin_process_host.h b/chrome/browser/plugin_process_host.h
index fb9dfe8..713c2d4 100644
--- a/chrome/browser/plugin_process_host.h
+++ b/chrome/browser/plugin_process_host.h
@@ -40,10 +40,10 @@ class PluginProcessHost : public IPC::Channel::Listener,
~PluginProcessHost();
// Initialize the new plugin process, returning true on success. This must
- // be called before the object can be used. If dll is the ActiveX-shim, then
- // activex_clsid is the class id of ActiveX control, otherwise activex_clsid
- // is ignored.
- bool Init(const FilePath& dll,
+ // be called before the object can be used. If plugin_path is the
+ // ActiveX-shim, then activex_clsid is the class id of ActiveX control,
+ // otherwise activex_clsid is ignored.
+ bool Init(const FilePath& plugin_path,
const std::string& activex_clsid,
const std::wstring& locale);